0.1.4_ (2022-12-13)
-------------------

- Support Python 3.10
- Avoid a bug with pyfftw 0.13

0.1.3_ (2021-09-29)
-------------------

- Many bugfixes!
- Improve VectorFieldOnGrid and ArrayOfVectorFieldsOnGrid
- UVmat compatibility
- Fix incompatibility OpenCV and PyQt5

0.1.2_ (2019-06-05)
-------------------

- Bugfix install Windows

0.1.1_ (2019-05-23)
-------------------

- Optical flow computation
- Bugfixes + internal code improvements

0.1.0 (2018-10-03)
------------------

- New topologies and executors with Trio!
- Much better coverage & many bugfixes!
- Better surface tracking

0.0.3 (2018-08-29)
------------------

- Requirement Python >= 3.6
- Surface tracking
- image2image preprocessing
- BOS topology
- Handle .cine file
- Calibration
- fluidimslideshow-pg and fluidimviewer-pg (based on PyQtgraph)
- OpenCV backend for preprocessing

0.0.2 (2017-04-13)
------------------

- Bug fixes and documentation changes.
- Continuous integration (python 2.7 and 3.5) with bitbucket pipelines
  (`coverage ~40% <https://codecov.io/gh/fluiddyn/fluidimage>`_)
- Preprocessing of images.
- First simple GUI (`fluidimviewer` and `fluidimlauncher`).

0.0.1b (2016-05-31)
-------------------

- Topology and waiting queues classes to run work in parallel.
- PIV work and topology (multipass, different correlation methods).

.. _0.1.3: https://foss.heptapod.net/fluiddyn/fluidimage/-/compare/0.1.3...0.1.4
.. _0.1.3: https://foss.heptapod.net/fluiddyn/fluidimage/-/compare/0.1.2...0.1.3
.. _0.1.2: https://foss.heptapod.net/fluiddyn/fluidimage/-/compare/0.1.1...0.1.2
.. _0.1.1: https://foss.heptapod.net/fluiddyn/fluidimage/-/compare/0.1.0...0.1.1
